ImageProvider class abstract

Base class for image providers.

Image providers are responsible for loading and decoding images from various sources (files, network, memory).

This follows Flutter's ImageProvider pattern.

Implementers

Constructors

ImageProvider()
Creates an image provider.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<ImageData>
Resolves this provider and returns the decoded image data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override