NetworkImage class
An image provider that loads an image from a URL.
Example:
Image(image: NetworkImage('https://example.com/image.png'))
- Inheritance
-
- Object
- ImageProvider
- NetworkImage
Constructors
- NetworkImage(String url)
-
Creates a network image provider.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
) → Future< ImageData> -
Resolves this provider and returns the decoded image data.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override